@@ -1,4 +1,3 @@
-// vim: set tabstop=4 shiftwidth=4 noexpandtab
 /*
 Gwenview - A simple image viewer for TDE
 Copyright 2000-2004 Aurlien Gteau
@@ -32,7 +31,7 @@ class Document;
 class DocumentLoadingImplPrivate;
 
 class DocumentLoadingImpl : public DocumentImpl {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	DocumentLoadingImpl(Document* document);
